==> open-cluster-management-apps-model-6.3.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ContactDataFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContactDataFluentImpl<A extends ContactDataFluent<A>> extends BaseFluent<A> implements ContactDataFluent<A>{
  public ContactDataFluentImpl() {
  }
  public ContactDataFluentImpl(ContactData instance) {
    this.withEmail(instance.getEmail()); 
    this.withName(instance.getName()); 
    this.withUrl(instance.getUrl()); 
  }
  private String email;
  private String name;
  private String url;
  public String getEmail() {
    return this.email;
  }
  public A withEmail(String email) {
    this.email=email; return (A) this;
  }
  public Boolean hasEmail() {
    return this.email != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ContactDataFluentImpl that = (ContactDataFluentImpl) o;
    if (email != null ? !email.equals(that.email) :that.email != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(email,  name,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (email != null) { sb.append("email:"); sb.append(email + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/app/k8s/v1beta1/ContactDataFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.app.k8s.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ContactDataFluentImpl<A extends ContactDataFluent<A>> extends BaseFluent<A> implements ContactDataFluent<A>{
  public ContactDataFluentImpl() {
  }
  public ContactDataFluentImpl(ContactData instance) {
    if (instance != null) {
      this.withEmail(instance.getEmail());
      this.withName(instance.getName());
      this.withUrl(instance.getUrl());
    }
  }
  private String email;
  private String name;
  private String url;
  public String getEmail() {
    return this.email;
  }
  public A withEmail(String email) {
    this.email=email; return (A) this;
  }
  public Boolean hasEmail() {
    return this.email != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ContactDataFluentImpl that = (ContactDataFluentImpl) o;
    if (!java.util.Objects.equals(email, that.email)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(email,  name,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (email != null) { sb.append("email:"); sb.append(email + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}
